@@ -1,7 +1,7 @@
 package Org::To::VCF;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -381,7 +381,7 @@ Org::To::VCF - Export contacts in Org document to VCF (vCard addressbook)
 
 =head1 VERSION
 
-This document describes version 0.07 of Org::To::VCF (from Perl distribution Org-To-VCF), released on 2015-08-18.
+This document describes version 0.08 of Org::To::VCF (from Perl distribution Org-To-VCF), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -437,7 +437,7 @@ drawer:
 
 =head2 org_to_vcf(%args) -> [status, msg, result, meta]
 
-{en_US Export contacts in Org document to VCF (vCard addressbook)}.
+Export contacts in Org document to VCF (vCard addressbook).
 
 Arguments ('*' denotes required arguments):
 
@@ -445,59 +445,51 @@ Arguments ('*' denotes required arguments):
 
 =item * B<default_country> => I<str>
 
-{en_US Specify default country code}.
+Specify default country code.
 
-{en_US 
 Free-form phone numbers on phone fields are formatted by this function, e.g.
 C<081 123 4567> becomes C<0811234567>. If default country is specified (e.g.
 "ID"), the number will be formatted as C<+62811234567>. Setting this option is
 recommended so the phone numbers are nicely formatted as international number.
-}
 
 =item * B<exclude_tags> => I<array[str]>
 
-{en_US Exclude trees that carry one of these tags}.
+Exclude trees that carry one of these tags.
 
-{en_US 
 If the whole document doesn't have any of these tags, then the whole document
 will be exported. Otherwise, trees that do not carry one of these tags will be
 excluded. If a selected tree is a subtree, the heading hierarchy above it will
 also be selected for export, but not the text below those headings.
 
 exclude_tags is evaluated after include_tags.
-}
 
 =item * B<export_notes> => I<bool> (default: 1)
 
-{en_US Whether to export note fields}.
+Whether to export note fields.
 
 =item * B<include_tags> => I<array[str]>
 
-{en_US Include trees that carry one of these tags}.
+Include trees that carry one of these tags.
 
-{en_US 
 Works like Org's 'org-export-select-tags' variable. If the whole document
 doesn't have any of these tags, then the whole document will be exported.
 Otherwise, trees that do not carry one of these tags will be excluded. If a
 selected tree is a subtree, the heading hierarchy above it will also be selected
 for export, but not the text below those headings.
-}
 
 =item * B<source_file> => I<str>
 
-{en_US Source Org file to export}.
+Source Org file to export.
 
 =item * B<source_str> => I<str>
 
-{en_US Alternatively you can specify Org string directly}.
+Alternatively you can specify Org string directly.
 
 =item * B<target_file> => I<str>
 
-{en_US VCF file to write to}.
+VCF file to write to.
 
-{en_US 
 If not specified, VCF output string will be returned instead.
-}
 
 =back
 
